Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(43)

Unified Diff: components/update_client/utils.h

Issue 2835803002: Refactor the UpdateEngine and its actions in the component updater. (Closed)
Patch Set: feedback up to #6 Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/update_client/update_engine.cc ('k') | components/update_client/utils.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/update_client/utils.h
diff --git a/components/update_client/utils.h b/components/update_client/utils.h
index 1c9e7414541829975c1af8c6bd2d79af1856d79e..2ab10b4664b98525972bcf4ac9d3d878689f7843 100644
--- a/components/update_client/utils.h
+++ b/components/update_client/utils.h
@@ -28,8 +28,8 @@ class URLRequestContextGetter;
namespace update_client {
+class Component;
struct CrxComponent;
-struct CrxUpdateItem;
// Defines a name-value pair that represents an installer attribute.
// Installer attributes are component-specific metadata, which may be serialized
@@ -89,8 +89,8 @@ bool FetchSuccess(const net::URLFetcher& fetcher);
// fetch is pending or canceled.
int GetFetchError(const net::URLFetcher& fetcher);
-// Returns true if the |update_item| contains a valid differential update url.
-bool HasDiffUpdate(const CrxUpdateItem* update_item);
+// Returns true if the |component| contains a valid differential update url.
+bool HasDiffUpdate(const Component& component);
// Returns true if the |status_code| represents a server error 5xx.
bool IsHttpServerError(int status_code);
« no previous file with comments | « components/update_client/update_engine.cc ('k') | components/update_client/utils.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698